==> opal-developer-tools_2.12-1.0.0-sources.jar: org/opalj/hermes/queries/BytecodeInstrumentationAPIUsage.scala <==
/* BSD 2-Clause License:
 * Copyright (c) 2009 - 2017
 * Software Technology Group
 * Department of Computer Science
 * Technische Universität Darmstadt
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  - Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *  - Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */
package org.opalj.hermes.queries

import org.opalj.br.ObjectType
import org.opalj.collection.immutable.Chain
import org.opalj.hermes.queries.util.APIFeature
import org.opalj.hermes.queries.util.APIFeatureGroup
import org.opalj.hermes.queries.util.APIFeatureQuery
import org.opalj.hermes.queries.util.InstanceAPIMethod

/**
 * Extracts basic information about the usage of the Java Instrumentation API that has been
 * enhanced in Java 6.
 *
 * @author Michael Reif
 */
object BytecodeInstrumentationAPIUsage extends APIFeatureQuery {

    override def apiFeatures: Chain[APIFeature] = {
        val Instrumentation = ObjectType("java/lang/instrument/Instrumentation")

        Chain(
            APIFeatureGroup(
                Chain(
                    InstanceAPIMethod(Instrumentation, "retransformClasses"),
                    InstanceAPIMethod(Instrumentation, "addTransformer"),
                    InstanceAPIMethod(Instrumentation, "isModifiableClass"),
                    InstanceAPIMethod(Instrumentation, "isRetransformClassesSupported"),
                    InstanceAPIMethod(Instrumentation, "isRedefineClassesSupported"),
                    InstanceAPIMethod(Instrumentation, "redefineClasses")
                ), "class file retransformation"
            ),

            APIFeatureGroup(
                Chain(
                    InstanceAPIMethod(Instrumentation, "setNativeMethodPrefix"),
                    InstanceAPIMethod(Instrumentation, "isNativeMethodPrefixSupported")
                ), "instrumenting native methods"
            ),

            APIFeatureGroup(
                Chain(
                    InstanceAPIMethod(Instrumentation, "appendToBootstrapClassLoaderSearch"),
                    InstanceAPIMethod(Instrumentation, "appendToSystemClassLoaderSearch")
                ), "appending class loader search"
            ),

            APIFeatureGroup(
                Chain(
                    InstanceAPIMethod(Instrumentation, "getAllLoadedClasses"),
                    InstanceAPIMethod(Instrumentation, "getInitiatedClasses"),
                    InstanceAPIMethod(Instrumentation, "getObjectSize")
                ), "retrieve classes information"
            )
        )
    }
}

==> opal-developer-tools_2.12-2.0.0-sources.jar: org/opalj/hermes/queries/BytecodeInstrumentationAPIUsage.scala <==
/* BSD 2-Clause License - see OPAL/LICENSE for details. */
package org.opalj.hermes
package queries

import org.opalj.br.ObjectType
import org.opalj.collection.immutable.Chain
import org.opalj.hermes.queries.util.APIFeature
import org.opalj.hermes.queries.util.APIFeatureGroup
import org.opalj.hermes.queries.util.APIFeatureQuery
import org.opalj.hermes.queries.util.InstanceAPIMethod

/**
 * Extracts basic information about the usage of the Java Instrumentation API that has been
 * enhanced in Java 6.
 *
 * @author Michael Reif
 */
class BytecodeInstrumentationAPIUsage(implicit hermes: HermesConfig) extends APIFeatureQuery {

    override def apiFeatures: Chain[APIFeature] = {
        val Instrumentation = ObjectType("java/lang/instrument/Instrumentation")

        Chain(
            APIFeatureGroup(
                Chain(
                    InstanceAPIMethod(Instrumentation, "retransformClasses"),
                    InstanceAPIMethod(Instrumentation, "addTransformer"),
                    InstanceAPIMethod(Instrumentation, "isModifiableClass"),
                    InstanceAPIMethod(Instrumentation, "isRetransformClassesSupported"),
                    InstanceAPIMethod(Instrumentation, "isRedefineClassesSupported"),
                    InstanceAPIMethod(Instrumentation, "redefineClasses")
                ), "class file retransformation"
            ),

            APIFeatureGroup(
                Chain(
                    InstanceAPIMethod(Instrumentation, "setNativeMethodPrefix"),
                    InstanceAPIMethod(Instrumentation, "isNativeMethodPrefixSupported")
                ), "instrumenting native methods"
            ),

            APIFeatureGroup(
                Chain(
                    InstanceAPIMethod(Instrumentation, "appendToBootstrapClassLoaderSearch"),
                    InstanceAPIMethod(Instrumentation, "appendToSystemClassLoaderSearch")
                ), "appending class loader search"
            ),

            APIFeatureGroup(
                Chain(
                    InstanceAPIMethod(Instrumentation, "getAllLoadedClasses"),
                    InstanceAPIMethod(Instrumentation, "getInitiatedClasses"),
                    InstanceAPIMethod(Instrumentation, "getObjectSize")
                ), "retrieve classes information"
            )
        )
    }
}
